@@ -10,14 +10,17 @@ __maintainer__ = "Tomas Poveda"
 __email__ = "tpovedatd@gmail.com"
 
 import os
+import locale
 import logging
 import inspect
-import traceback
+import tempfile
 import importlib
 
-import tpDccLib as tp
-from tpPyUtils import python, decorators, path as path_utils
-from tpQtLib.core import qtutils
+import six
+
+import tpDcc as tp
+from tpDcc.libs.python import python, decorators, osplatform, path as path_utils
+from tpDcc.libs.qt.core import qtutils
 
 if python.is_python2():
     import pkgutil as loader
@@ -26,7 +29,6 @@ else:
 
 import artellapipe
 import artellapipe.register
-from artellapipe.core import config
 from artellapipe.libs import artella as artella_lib
 from artellapipe.libs.artella.core import artellalib
 from artellapipe.libs.naming.core import naminglib
@@ -40,7 +42,7 @@ class ArtellaFilesManager(object):
         self._project = None
         self._config = None
 
-        self._registered_file_clases = dict()
+        self._registered_file_classes = dict()
 
     @property
     def config(self):
@@ -52,7 +54,7 @@ class ArtellaFilesManager(object):
 
     @property
     def file_classes(self):
-        return self._registered_file_clases.values()
+        return self._registered_file_classes.values()
 
     def set_project(self, project):
         """
@@ -61,7 +63,12 @@ class ArtellaFilesManager(object):
         """
 
         self._project = project
-        self._config = config.get_config(project, 'artellapipe-files')
+        self._config = tp.ConfigsMgr().get_config(
+            config_name='artellapipe-files',
+            package_name=self._project.get_clean_name(),
+            root_package_name='artellapipe',
+            environment=project.get_environment()
+        )
 
         self._register_file_classes()
 
@@ -72,7 +79,7 @@ class ArtellaFilesManager(object):
         :param file_class: class
         """
 
-        self._registered_file_clases[file_type] = file_class
+        self._registered_file_classes[file_type] = file_class
         return True
 
     def get_file_class(self, file_type_name):
@@ -86,7 +93,7 @@ class ArtellaFilesManager(object):
             LOGGER.warning('File Type with name "{}" not registered!'.format(file_type_name))
             return
 
-        return self._registered_file_clases[file_type_name]
+        return self._registered_file_classes[file_type_name]
 
     def check_file_type(self, file_type_name):
         """
@@ -95,11 +102,20 @@ class ArtellaFilesManager(object):
         :return: bool
         """
 
-        if file_type_name not in self._registered_file_clases:
+        if file_type_name not in self._registered_file_classes:
             return False
 
         return True
 
+    def is_valid_file_type(self, file_type):
+        """
+        Returns whether the current file type is valid or not for current project
+        :param file_type: str
+        :return: bool
+        """
+
+        return file_type in self.files
+
     def get_file_type_info(self, file_type):
         """
         Returns dictionary with the information of the given file type
@@ -112,6 +128,21 @@ class ArtellaFilesManager(object):
 
         return self.files[file_type] if file_type in self.files else dict()
 
+    def get_file_type_name(self, file_type):
+        """
+        Returns nice name of the given file type
+        :param file_type: str
+        :return: str
+        """
+
+        if not self.files:
+            return
+
+        if file_type not in self.files:
+            return file_type
+
+        return self.files[file_type].get('name', file_type)
+
     def get_file_type_extensions(self, file_type):
         """
         Returns extensions of the given file type
@@ -134,7 +165,7 @@ class ArtellaFilesManager(object):
             return None
 
         valid_file_types = list()
-        for file_type_name, file_type_class in self._registered_file_clases.items():
+        for file_type_name, file_type_class in self._registered_file_classes.items():
             if file_type_extension in file_type_class.FILE_EXTENSIONS:
                 valid_file_types.append(file_type_class)
 
@@ -153,6 +184,14 @@ class ArtellaFilesManager(object):
 
         return template
 
+    def parse_path(self, path):
+        all_templates = naminglib.ArtellaNameLib().templates
+        for template in all_templates:
+            path_dict = naminglib.ArtellaNameLib().parse_template(template.name, path)
+            if not path_dict:
+                continue
+            return path_dict
+
     def fix_path(self, path_to_fix):
         """
         Converts path to a path relative to project environment variable
@@ -208,16 +247,49 @@ class ArtellaFilesManager(object):
         :return: str
         """
 
+        self._check_project()
+
         path_to_resolve = path_to_resolve.replace('\\', '/')
         project_var = os.environ.get(self._project.env_var)
         if not project_var:
             return path_to_resolve
 
         if path_to_resolve.startswith(project_var):
-            path_to_resolve = path_to_resolve.replace(project_var, '${}/'.format(self.env_var))
+            path_to_resolve = path_to_resolve.replace(project_var, '${}/'.format(self._project.env_var))
 
         return path_to_resolve
 
+    def prefix_path_with_project_path(self, path_to_prefix, env_var=False):
+        """
+        Adds project path to given path as prefix
+        :param path_to_prefix: str
+        :return: str
+        """
+
+        self._check_project()
+
+        if env_var:
+            project_env_var = self._project.env_var
+            path_to_prefix = path_to_prefix.replace('\\', '/')
+            project_var = os.environ.get(project_env_var)
+            return path_utils.clean_path(os.path.join(project_var, path_to_prefix))
+        else:
+            return path_utils.clean_path(os.path.join(self._project.get_path(), path_to_prefix))
+
+    def prefix_path_with_artella_env_path(self, path_to_prefix):
+        """
+        Adds Artella environment variable path to given path as prefix
+        :param path_to_prefix: str
+        :return: str
+        """
+
+        root_prefix = artella_lib.config.get('app', 'root_prefix')
+        artella_var = os.environ.get(root_prefix, None)
+        if not artella_var:
+            return path_to_prefix
+
+        return path_utils.clean_path(os.path.join(artella_var, path_to_prefix))
+
     def sync_files(self, files):
         """
         Synchronizes given files from Artella server into user hard drive
@@ -285,7 +357,7 @@ class ArtellaFilesManager(object):
             return False
 
         if notify:
-            self._project.tray.show_message(title='Lock File', msg='File locked successfully!')
+            self._project.notify(title='Lock File', msg='File "{}" locked successfully!'.format(file_path))
 
         return True
 
@@ -322,7 +394,7 @@ class ArtellaFilesManager(object):
 
         artellalib.unlock_file(file_path=file_path)
         if notify:
-            self.tray.show_message(title='Unlock File', msg='File unlocked successfully!')
+            self._project.notify(title='Unlock File', msg='File "{}" unlocked successfully!'.format(file_path))
 
         return True
 
@@ -414,9 +486,10 @@ class ArtellaFilesManager(object):
         if comment:
             artellalib.upload_new_asset_version(file_path=file_path, comment=comment, skip_saving=skip_saving)
             if notify:
-                self.tray.show_message(
-                    title='New Working Version', msg='Version {} uploaded to Artella server successfully!'.format(
-                        current_version))
+                self._project.notify(
+                    title='New Working Version',
+                    msg='Version {} for file "{}" uploaded to Artella server successfully!'.format(
+                        current_version, file_path))
             return True
 
         return False
@@ -445,16 +518,60 @@ class ArtellaFilesManager(object):
                 return False
 
         if not file_path.startswith(self._project.get_path()):
-            LOGGER.error('Impossible to lock file that is nos located in {} Project Folder!'.format(self.name))
+            LOGGER.error('Impossible to lock file that is nos located in {} Project Folder!'.format(file_path))
             return
 
         if not os.path.isfile(file_path):
             LOGGER.error('File {} cannot be locked because it does not exists!'.format(file_path))
             return False
-            return False
 
         return True
 
+    def _format_path(self, format_string, path='', **kwargs):
+        """
+        Resolves the given string with the given path and keyword arguments
+        :param format_string: str
+        :param path: str
+        :param kwargs: dict
+        :return: str
+        """
+
+        LOGGER.debug('Format String: {}'.format(format_string))
+
+        dirname, name, extension = path_utils.split_path(path)
+        encoding = locale.getpreferredencoding()
+        temp = tempfile.gettempdir()
+        if temp:
+            temp = temp.decode(encoding)
+
+        username = osplatform.get_user().lower()
+        if username:
+            username = username.decode(encoding)
+
+        local = os.getenv('APPDATA') or os.getenv('HOME')
+        if local:
+            local = local.decode(encoding)
+
+        kwargs.update(os.environ)
+
+        labels = {
+            "name": name,
+            "path": path,
+            "user": username,
+            "temp": temp,
+            "local": local,
+            "dirname": dirname,
+            "extension": extension,
+        }
+
+        kwargs.update(labels)
+
+        resolved_string = six.u(str(format_string)).format(**kwargs)
+
+        LOGGER.debug('Resolved string: {}'.format(resolved_string))
+
+        return path_utils.clean_path(resolved_string)
+
     def _register_file_classes(self):
         """
         Internal function that registers file classes
@@ -464,7 +581,7 @@ class ArtellaFilesManager(object):
             LOGGER.warning('Impossible to register file classes because Artella project is not defined!')
             return False
 
-        for file_type, file_info in self._config.get('files', default={}).items():
+        for file_type, file_info in self._config.get('files', default=dict()).items():
             full_file_class = file_info.get('class', None)
             if not full_file_class:
                 LOGGER.warning('No class defined for File Type "{}". Skipping ...'.format(file_type))
